@@ -1,5 +1,7 @@
-from bcsim import Ball
-from bcsim import Rail
+"""Clock classes."""
+
+from bcsim.rail import Ball
+from bcsim.rail import Rail
 
 
 class Clock:
