@@ -1,19 +1,21 @@
+"""Functions to manage the running of the clocks."""
+
 import curses
 import multiprocessing as mp
 import os
 from datetime import datetime as dt
 
-from bcsim import Clock
-from bcsim import FastClock
+from bcsim.clocks import Clock
+from bcsim.clocks import FastClock
 
 
 def clear():
-    """Clear the screen
+    """Clear the screen.
 
     This is an os-agnostic version, which will work with both Windows
     and Linux.
     """
-    return os.system('clear' if os.name == 'posix' else 'cls')
+    os.system('clear' if os.name == 'posix' else 'cls')
 
 # --------------------------------------------------------------------
 
@@ -77,7 +79,15 @@ def runClock(balls, q, fast=False):
 
 
 def runSimulation(stdscr, args):
+    """Run a selected number of clocks.
 
+    Parameters
+    ----------
+    stdscr : curses
+        Allows for screen manipulation using the curses module.
+    args : argparse
+        Command line inputs capture from the argument parser.
+    """
     stdscr.clear()
     curses.curs_set(0)
 
